/*
 * Copyright (c) 2011-2015, The University of Oxford
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the University of Oxford nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */


#ifndef OSKAR_VERSION_H_
#define OSKAR_VERSION_H_

/**
 * @def OSKAR_VERSION
 *
 * @brief OSKAR_VERSION is a macro used to determine the version of OSKAR.
 *
 * @details
 * This macro expands to a numeric value of the form 0xMMNNPP (MM = major,
 * NN = minor, PP = patch) that specifies the version number of the OSKAR
 * library. For example, in OSKAR version 2.1.3 this would expand to
 * 0x020103.
 * NOTE this value is set in the CMake build system
 */
#define OSKAR_VERSION 0x020803

/**
 * @def OSKAR_VERSION_STR
 *
 * @brief OSKAR_VERSION_STR is a macro used to return the version of OSKAR as
 * a text string.
 *
 * @details
 * This macro expands to a string that specifies the OSKAR version number
 * (for example, "2.1.3").
 * NOTE this value is set in the CMake build system
 */
#define OSKAR_VERSION_STR "2.8.3"

#endif /* OSKAR_VERSION_H_ */
