/*
 * Copyright (c) 2013, The University of Oxford
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the University of Oxford nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef OSKAR_STATION_LOAD_PERMITTED_BEAMS_H_
#define OSKAR_STATION_LOAD_PERMITTED_BEAMS_H_

/**
 * @file oskar_station_load_permitted_beams.h
 */

#include <oskar_global.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief
 * Loads permitted station beam directions from a text file.
 *
 * @details
 * This function loads station permitted beam directions from a comma- or
 * space-separated text file. Each line contains data for one beam direction.
 *
 * The file should have the following columns, in the following order:
 * - Permitted beam azimuth in degrees.
 * - Permitted beam elevation in degrees.
 *
 * The azimuth and elevation angles are defined in the usual sense with respect
 * to the station. (Azimuth is the angle east of local north, and elevation
 * increases from the horizon to the zenith.)
 *
 * @param[out] station   Pointer to destination data structure to fill.
 * @param[in] filename   Name of the data file to load.
 * @param[in,out] status Status return code.
 */
OSKAR_EXPORT
void oskar_station_load_permitted_beams(oskar_Station* station,
        const char* filename, int* status);

#ifdef __cplusplus
}
#endif

#endif /* OSKAR_STATION_LOAD_PERMITTED_BEAMS_H_ */
